
/* Generated data (by glib-mkenums) */

#ifndef E_UTIL_ENUMTYPES_H
#define E_UTIL_ENUMTYPES_H

#include <glib-object.h>

G_BEGIN_DECLS

/* Enumerations from "./e-util-enums.h" */

#define E_TYPE_ACTIVITY_STATE	(e_activity_state_get_type())
GType e_activity_state_get_type	(void) G_GNUC_CONST;

#define E_TYPE_AUTOMATIC_ACTION_POLICY	(e_automatic_action_policy_get_type())
GType e_automatic_action_policy_get_type	(void) G_GNUC_CONST;

#define E_TYPE_DATE_WEEKDAY	(e_date_weekday_get_type())
GType e_date_weekday_get_type	(void) G_GNUC_CONST;

#define E_TYPE_DURATION_TYPE	(e_duration_type_get_type())
GType e_duration_type_get_type	(void) G_GNUC_CONST;

G_END_DECLS

#endif /* E_UTIL_ENUMTYPES_H */

/* Generated data ends here */

